require_relative 'player'
require_relative 'game_turn'
require_relative 'treasure_trove'

module StudioGame
  class Game
    attr_reader :title

    def initialize(title)
      @title = title.capitalize
      @players = []
    end

    def add_player(player)
      @players << player
    end

    def play(rounds)
      puts "There are #{@players.size} players in #{title}:"
      puts @players

      treasures = TreasureTrove::TREASURES
      puts "\nThere are #{treasures.size} treasures to be found:"
      treasures.each do |t|
        puts "A #{t.name} is worth #{t.points} points"
      end

      1.upto(rounds) do |round|
        puts "\nRound #{round}:"
        @players.each do |player|
          GameTurn.take_turn(player)
        end
      end
    end

    def print_stats
      strong_players, wimpy_players = @players.partition { |p| p.strong? }
      sorted_players = @players.sort
      
      puts "Knuckleheads Stats:\n"
      puts "#{strong_players.size} strong players:"
      strong_players.each do |player|
        print_name_and_health(player)
      end
      
      puts ""
      puts "#{wimpy_players.size} wimpy players:"
      wimpy_players.each do |player|
        print_name_and_health(player)
      end
      
      puts ""
      puts "Knuckleheads High Scores:"
      sorted_players.each do |player|
        puts high_score_entry(player)
      end

      @players.sort.each do |player|
        puts "\n#{player.name}'s point totals:"
        player.each_found_treasure do |treasure|
          puts "#{treasure.points} total #{treasure.name} points"
        end
        puts "#{player.points} grand total points"
      end
    end

    def print_name_and_health(player)
      puts "#{player.name} (#{player.health})"
    end

    def load_players(from_file)
      File.readlines(from_file).each do |line|
        # name, health = line.split(",")
        # health = health.to_i
        add_player(Player.from_csv(line))
        # add_player(Player.new(name, health))
      end
    end

    def save_high_scores(to_file = "high_scores.txt")
      File.open(to_file, "w") do |file|
        file.puts "#{@title} High Scores:"
        @players.sort.each do |player|
          file.puts high_score_entry(player)
        end
      end
    end

    def high_score_entry(player)
      "#{player.name}".ljust(20, ".") + " #{player.score}"
    end
  end
end
