require_relative 'treasure_trove'
require_relative 'playable'

module StudioGame
  class Player
    include Playable
    attr_accessor :name
    attr_reader :health

    def initialize(name, health = 100)
      @name = name.capitalize
      @health = health
      @found_treasures = Hash.new(0)
    end

    def to_s
      "I'm #{@name} with health = #{@health}, points = #{points}, and score = #{score}."
    end

    def each_found_treasure
      @found_treasures.each do |name, points|
        yield(Treasure.new(name, points))
      end
    end

    def found_treasure(treasure)
      @found_treasures[treasure.name] += treasure.points
      puts "#{@name} found a #{treasure.name} worth #{treasure.points} points."
    end

    def points
      @found_treasures.values.reduce(0, :+)
    end

    def time
      current_time = Time.new
      current_time.strftime("%I:%M:%S")
    end

    def <=>(other_player)
      other_player.score <=> score
    end

    def self.from_csv(formated_player)
      name, health = formated_player.split(",")
      Player.new(name, health.to_i)
    end
  end

  if __FILE__ == $PROGRAM_NAME
    player = Player.new("moe")
    puts player.name
    puts player.health
    player.w00t
    puts player.health
    player.blam
    puts player.health
  end
end